# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

{
    'name': 'OdooBot for livechat',
    'version': '1.0',
    'category': 'Productivity/Discuss',
    'summary': 'Add livechat support for OdooBot',
    'description': "",
    'website': 'https://www.odoo.com/app/discuss',
    'depends': ['mail_bot', 'im_livechat'],
    'installable': True,
    'application': False,
    'auto_install': True,
    'license': 'LGPL-3',
}
